local addonName = "Broker_HealBot"
Broker_HealBot = {}
local addon = Broker_HealBot
local _G = getfenv(0)
local defaults = { 
  HideMinimap = true,
  DebugEnabled = false,
}
local settings = defaults
local LDB, LDBo
BHB_svnrev = {}
BHB_svnrev["Broker_HealBot.lua"] = tonumber(("$Revision: 8 $"):match("%d+"))


local function chatMsg(msg)
     DEFAULT_CHAT_FRAME:AddMessage(addonName..": "..msg)
end
local function debug(msg)
  if settings.DebugEnabled then
     chatMsg(msg)
  end
end

local frame = CreateFrame("Button", addonName.."HiddenFrame", UIParent)
frame:RegisterEvent("ADDON_LOADED");

local function OnEvent(frame, event, name, ...)
  if event == "ADDON_LOADED" and name == addonName then
     debug("ADDON_LOADED: "..name)
     addon:setupLDB()
     addon:SetupVersion()
     Broker_HealBotDB = Broker_HealBotDB or {}
     if not Broker_HealBotDB.settings then
         Broker_HealBotDB.settings = {}
         for k,v in pairs(defaults) do
           Broker_HealBotDB.settings[k] = v
         end
     end
     settings = Broker_HealBotDB.settings
     settings.loaded = true
     if (LDBo) then
       addon:HideMinimap()
     end
  elseif event == "ADDON_LOADED" then
     debug("ADDON_LOADED: "..name)
     addon:setupLDB()
  end
end
frame:SetScript("OnEvent", OnEvent);

SLASH_BROKERHEALBOT1 = "/bhb"
SlashCmdList["BROKERHEALBOT"] = function(msg)
        local cmd = msg:lower()
        if cmd == "minimap" then
          chatMsg("healbot minimap toggled")
          settings.HideMinimap = not settings.HideMinimap
          addon:HideMinimap()
        elseif cmd == "debug" then
          chatMsg("debug toggled")
          settings.DebugEnabled = not settings.DebugEnabled
        else
          chatMsg(addonName.." "..addon.version)
          chatMsg(SLASH_BROKERHEALBOT1.." [ minimap | debug ]")
        end
end

function addon:SetupVersion()
   local svnrev = 0
   local T_svnrev = BHB_svnrev
   T_svnrev["X-Build"] = tonumber((GetAddOnMetadata(addonName, "X-Build") or ""):match("%d+"))
   T_svnrev["X-Revision"] = tonumber((GetAddOnMetadata(addonName, "X-Revision") or ""):match("%d+"))
   for _,v in pairs(T_svnrev) do -- determine highest file revision
     if v and v > svnrev then
       svnrev = v
     end
   end
   addon.revision = svnrev

   T_svnrev["X-Curse-Packaged-Version"] = GetAddOnMetadata(addonName, "X-Curse-Packaged-Version")
   T_svnrev["Version"] = GetAddOnMetadata(addonName, "Version")
   addon.version = T_svnrev["X-Curse-Packaged-Version"] or T_svnrev["Version"] or "@"
   if string.find(addon.version, "@") then -- dev copy uses "@.project-version.@"
      addon.version = "r"..svnrev
   end
end

function addon:HideMinimap()
   if ( settings.HideMinimap ) then
      -- hide healbot's regular icon
      _G.HealBot_Options_ShowMinimapButton:SetChecked(false);
      _G.HealBot_Config.ButtonShown = 0;
      debug("minimap hidden")
   else
      -- show it
      _G.HealBot_Options_ShowMinimapButton:SetChecked(true);
      _G.HealBot_Config.ButtonShown = 1;
      debug("minimap shown")
   end
   _G.HealBot_MMButton_Init();
end

function addon:setupLDB()
  if LDB then
    return
  end
  if AceLibrary and AceLibrary:HasInstance("LibDataBroker-1.1") then
    LDB = AceLibrary("LibDataBroker-1.1")
  elseif LibStub then
    LDB = LibStub:GetLibrary("LibDataBroker-1.1",true)
  end
  if LDB then
    LDBo = LDB:NewDataObject("Broker_HealBot", {
        type = "launcher",
        label = "HealBot",
        icon = "Interface\\AddOns\\Broker_HealBot\\icon",
        OnClick = function(self, button)
                if button == "LeftButton" then
                   if ( IsShiftKeyDown() ) then
		       debug("HB reset")
                       _G.HealBot_SetResetFlag("SOFT");
		       if InCombatLockdown() then
		         chatMsg("Healbot reset requested (in combat)")
		       end
                   else
  		       debug("skin menu")
        	       if addon.tooltip and addon.tooltip:IsVisible() then
        	         addon.tooltip:Hide()
        	       end
        	       ToggleDropDownMenu(1, nil, addon.DropDownMenu, self, 0, 0)
                   end
                elseif button == "RightButton" then
                   if ( IsShiftKeyDown() ) then                
  		       debug("HB toggle")
                       local curval = _G.HealBot_Config.DisableHealBot
                       _G.HealBot_Options_ToggleHealBot(1-curval)
		       if InCombatLockdown() then
		          chatMsg("Healbot toggle requested (in combat)")
		       end
		   else
                       debug("HB options")
                       _G.HealBot_ToggleOptions();		   
		   end
		else

                end
        end,
        OnTooltipShow = function(tooltip)
                addon.tooltip = tooltip
                if tooltip and tooltip.AddLine then
                        tooltip:SetText(addonName.." "..addon.version)
                        tooltip:AddLine("|cffff8040Left Click|r to choose Healbot skin")
                        tooltip:AddLine("|cffff8040Right Click|r to open HealBot options")
                        tooltip:AddLine("|cffff8040Shift Left Click|r to reset HealBot")
                        tooltip:AddLine("|cffff8040Shift Right Click|r to toggle HealBot")
                        tooltip:Show()
                end
        end,
     })
     debug("LDB created!")
     if (settings.loaded) then
       addon:HideMinimap()
     end
  end 
end

addon.DropDownMenu = CreateFrame("Frame", addonName.."_DropDownMenu")
addon.DropDownMenu.displayMode = "MENU"
addon.DropDownMenu.onHide = function(...)
        MenuParent = nil
        MenuItem = nil
end

local menuinfo = {}
addon.DropDownMenu.initialize = function(self, level)
        if not level then return end
        wipe(menuinfo)
        if level == 1 then
                -- Create the title of the menu
                menuinfo.isTitle = 1
                menuinfo.text = "Healbot Skins:"
                menuinfo.notCheckable = 1
                UIDropDownMenu_AddButton(menuinfo, level)

                menuinfo.disabled     = nil
                menuinfo.isTitle      = nil
                menuinfo.notCheckable = nil

                local skins = _G.Healbot_Config_Skins.Skins
                local curskin = _G.Healbot_Config_Skins.Current_Skin
                for _,s in pairs(skins) do
                        menuinfo.text = s
                        menuinfo.arg1 = s
                        menuinfo.func = function(button, arg1)
                                HealBot_Options_Set_Current_Skin(s)
        		        if InCombatLockdown() then
        		           chatMsg("Healbot skin change requested (in combat)")
        		        else
                                   chatMsg("Healbot skin set to: "..s)        		       
        		        end                                
                        end
                        menuinfo.checked = (s == curskin)
                        UIDropDownMenu_AddButton(menuinfo, level)
                end

                -- Close menu item
                menuinfo.text         = CLOSE
                menuinfo.func         = function() CloseDropDownMenus() end
                menuinfo.checked      = nil
                menuinfo.notCheckable = 1
                UIDropDownMenu_AddButton(menuinfo, level)
        end
end
